Stan Math Library: stan::math::container_view< T1, T2 > Class Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Member Functions | List of all members
stan::math::container_view< T1, T2 > Class Template Reference

Primary template class for container view of array y with same structure as T1 and size as x. More...

`#include <container_view.hpp>`

## Public Member Functions
| container_view (const T1 &x, T2 *y)
| Constructor. More...
T2 & | operator[] (int i)
| operator[](int i) returns reference to view, indexed by i Specialization handle appropriate broadcasting if size of x is 1 More...

## Detailed Description

### template<typename T1, typename T2>
class stan::math::container_view< T1, T2 >

Primary template class for container view of array y with same structure as T1 and size as x.

Template Parameters

  T1 | type of view.
  T2 | type of scalar returned by view.

Definition at line 22 of file container_view.hpp.

## Constructor & Destructor Documentation

template<typename T1 , typename T2 >

stan::math::container_view< T1, T2 >::container_view | ( | const T1 & | x,
|  | T2 * | y
| ) |  |
| inline

Constructor.

Parameters

  x | object from which size is to be inferred
  y | underlying array

Definition at line 30 of file container_view.hpp.

## Member Function Documentation

template<typename T1 , typename T2 >

T2& stan::math::container_view< T1, T2 >::operator[] | ( | int | i | ) |
| inline

operator[](int i) returns reference to view, indexed by i Specialization handle appropriate broadcasting if size of x is 1

Parameters

  i | index

Definition at line 40 of file container_view.hpp.

The documentation for this class was generated from the following file:

- stan/math/prim/scal/meta/container_view.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.